#ifndef NT2_INCLUDE_CONSTANTS_ONEO_120_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_ONEO_120_HPP_INCLUDED

#include <nt2/constant/include/constants/oneo_120.hpp>

#endif
